@@ -51,30 +51,20 @@ class InterceptFlowTestConfiguration(FlowTestConfiguration):
 
 
 def assert_is_bad_run(ret_value):
-    assert ret_value is not 0, "This test should have a FAILURE return code, but returned 0"
+    assert ret_value != 0, "This test should have a FAILURE return code, but returned 0"
 
 
 def assert_is_good_run(ret_value):
-    assert ret_value is 0, "Test expects a CLEAN run, but returned %s. " \
+    assert ret_value == 0, "Test expects a CLEAN run, but returned %s. " \
                            "Check the err output to see what went wrong." % str(ret_value)
 
 
-def skip_test_unless(cls, condition, reason=None):
-    if condition:
-        setattr(cls, "skip_test", True)
-        if reason:
-            print(reason)
+def skip_test(cls):
+    setattr(cls, "skip_test", True)
     return cls
 
 
-def skip_test(cls, reason=None):
-    return skip_test_unless(cls,
-                            condition=True,
-                            reason=reason)
-
-
 def discover_tests(tests, config_filter="") -> list:
-
     configs = []
     for tests_path in tests.split(","):
 
